@@ -53,7 +53,8 @@ type Config struct {
 	// Deprecated
 	OSC99 bool `json:"osc99,omitempty"`
 
-	Output string `json:"-"`
+	Output        string `json:"-"`
+	MigrateGlyphs bool   `json:"-"`
 
 	format string
 	origin string
@@ -88,10 +89,9 @@ func (cfg *Config) getPalette() ansi.Palette {
 // LoadConfig returns the default configuration including possible user overrides
 func LoadConfig(env platform.Environment) *Config {
 	cfg := loadConfig(env)
-	cfg.env = env
 	// only migrate automatically when the switch isn't set
 	if !env.Flags().Migrate && cfg.Version < configVersion {
-		cfg.BackupAndMigrate(env)
+		cfg.BackupAndMigrate()
 	}
 	return cfg
 }
@@ -101,12 +101,14 @@ func loadConfig(env platform.Environment) *Config {
 	configFile := env.Flags().Config
 
 	if len(configFile) == 0 {
-		return defaultConfig(false)
+		env.Debug("no config file specified, using default")
+		return defaultConfig(env, false)
 	}
 
 	var cfg Config
 	cfg.origin = configFile
 	cfg.format = strings.TrimPrefix(filepath.Ext(configFile), ".")
+	cfg.env = env
 	if cfg.format == "yml" {
 		cfg.format = YAML
 	}
@@ -125,12 +127,14 @@ func loadConfig(env platform.Environment) *Config {
 
 	err := config.LoadFiles(configFile)
 	if err != nil {
-		return defaultConfig(true)
+		env.Error(err)
+		return defaultConfig(env, true)
 	}
 
 	err = config.BindStruct("", &cfg)
 	if err != nil {
-		return defaultConfig(true)
+		env.Error(err)
+		return defaultConfig(env, true)
 	}
 
 	return &cfg
@@ -177,7 +181,7 @@ func (cfg *Config) Export(format string) string {
 		_ = jsonEncoder.Encode(cfg)
 		prefix := "{\n  \"$schema\": \"https://raw.githubusercontent.com/JanDeDobbeleer/oh-my-posh/main/themes/schema.json\","
 		data := strings.Replace(result.String(), "{", prefix, 1)
-		return escapeGlyphs(data)
+		return escapeGlyphs(data, cfg.MigrateGlyphs)
 	}
 
 	_, _ = config.DumpTo(&result, cfg.format)
@@ -187,15 +191,15 @@ func (cfg *Config) Export(format string) string {
 		return prefix + result.String()
 	case TOML:
 		prefix := "#:schema https://raw.githubusercontent.com/JanDeDobbeleer/oh-my-posh/main/themes/schema.json\n\n"
-		return prefix + escapeGlyphs(result.String())
+		return prefix + escapeGlyphs(result.String(), cfg.MigrateGlyphs)
 	default:
 		return result.String()
 	}
 }
 
-func (cfg *Config) BackupAndMigrate(env platform.Environment) {
-	cfg.backup()
-	cfg.Migrate(env)
+func (cfg *Config) BackupAndMigrate() {
+	cfg.Backup()
+	cfg.Migrate()
 	cfg.Write(cfg.format)
 }
 
@@ -216,7 +220,7 @@ func (cfg *Config) Write(format string) {
 	_ = f.Close()
 }
 
-func (cfg *Config) backup() {
+func (cfg *Config) Backup() {
 	dst := cfg.origin + ".bak"
 	source, err := os.Open(cfg.origin)
 	if err != nil {
@@ -234,7 +238,7 @@ func (cfg *Config) backup() {
 	}
 }
 
-func escapeGlyphs(s string) string {
+func escapeGlyphs(s string, migrate bool) string {
 	shouldExclude := func(r rune) bool {
 		if r < 0x1000 { // Basic Multilingual Plane
 			return true
@@ -266,6 +270,11 @@ func escapeGlyphs(s string) string {
 		return false
 	}
 
+	var cp codePoints
+	if migrate {
+		cp = getGlyphCodePoints()
+	}
+
 	var builder strings.Builder
 	for _, r := range s {
 		// exclude regular characters and emojis
@@ -274,6 +283,12 @@ func escapeGlyphs(s string) string {
 			continue
 		}
 
+		if migrate {
+			if val, OK := cp[int(r)]; OK {
+				r = rune(val)
+			}
+		}
+
 		if r > 0x10000 {
 			// calculate surrogate pairs
 			one := 0xd800 + (((r - 0x10000) >> 10) & 0x3ff)
@@ -289,7 +304,7 @@ func escapeGlyphs(s string) string {
 	return builder.String()
 }
 
-func defaultConfig(warning bool) *Config {
+func defaultConfig(env platform.Environment, warning bool) *Config {
 	exitBackgroundTemplate := "{{ if gt .Code 0 }}p:red{{ end }}"
 	exitTemplate := " {{ if gt .Code 0 }}\uf00d{{ else }}\uf00c{{ end }} "
 	if warning {
@@ -477,5 +492,6 @@ func defaultConfig(warning bool) *Config {
 			},
 		},
 	}
+	cfg.env = env
 	return cfg
 }
