@@ -264,3 +264,12 @@ func (env *MockedEnvironment) DirIsWritable(path string) bool {
 	args := env.Called(path)
 	return args.Bool(0)
 }
+
+func (env *MockedEnvironment) SetPromptCount() {
+	_ = env.Called()
+}
+
+func (env *MockedEnvironment) CursorPosition() (int, int) {
+	args := env.Called()
+	return args.Int(0), args.Int(1)
+}
