@@ -34,7 +34,7 @@ const (
 	LINUX   = "linux"
 )
 
-func getPID() string {
+func pid() string {
 	pid := os.Getenv("POSH_PID")
 	if len(pid) == 0 {
 		pid = strconv.Itoa(os.Getppid())
@@ -43,8 +43,9 @@ func getPID() string {
 }
 
 var (
-	TEMPLATECACHE = fmt.Sprintf("template_cache_%s", getPID())
-	TOGGLECACHE   = fmt.Sprintf("toggle_cache_%s", getPID())
+	TEMPLATECACHE    = fmt.Sprintf("template_cache_%s", pid())
+	TOGGLECACHE      = fmt.Sprintf("toggle_cache_%s", pid())
+	PROMPTCOUNTCACHE = fmt.Sprintf("prompt_count_cache_%s", pid())
 )
 
 type Flags struct {
@@ -63,6 +64,8 @@ type Flags struct {
 	Debug         bool
 	Manual        bool
 	Plain         bool
+	Primary       bool
+	PromptCount   int
 }
 
 type CommandError struct {
@@ -148,6 +151,7 @@ type TemplateCache struct {
 	Env          map[string]string
 	OS           string
 	WSL          bool
+	PromptCount  int
 	Segments     SegmentsCache
 
 	sync.RWMutex
@@ -159,6 +163,12 @@ func (t *TemplateCache) AddSegmentData(key string, value interface{}) {
 	t.Unlock()
 }
 
+func (t *TemplateCache) RemoveSegmentData(key string) {
+	t.Lock()
+	delete(t.Segments, key)
+	t.Unlock()
+}
+
 type Environment interface {
 	Getenv(key string) string
 	Pwd() string
@@ -205,6 +215,8 @@ type Environment interface {
 	Connection(connectionType ConnectionType) (*Connection, error)
 	TemplateCache() *TemplateCache
 	LoadTemplateCache()
+	SetPromptCount()
+	CursorPosition() (row, col int)
 	Debug(message string)
 	Error(err error)
 	Trace(start time.Time, args ...string)
@@ -254,6 +266,7 @@ func (env *Shell) Init() {
 	env.cmdCache = &commandCache{
 		commands: NewConcurrentMap(),
 	}
+	env.SetPromptCount()
 }
 
 func (env *Shell) resolveConfigPath() {
@@ -262,11 +275,13 @@ func (env *Shell) resolveConfigPath() {
 		env.CmdFlags.Config = env.Getenv("POSH_THEME")
 	}
 	if len(env.CmdFlags.Config) == 0 {
+		env.Debug("No config set, fallback to default config")
 		return
 	}
 	if strings.HasPrefix(env.CmdFlags.Config, "https://") {
 		if err := env.downloadConfig(env.CmdFlags.Config); err != nil {
 			// make it use default config when download fails
+			env.Error(err)
 			env.CmdFlags.Config = ""
 			return
 		}
@@ -274,6 +289,7 @@ func (env *Shell) resolveConfigPath() {
 	// Cygwin path always needs the full path as we're on Windows but not really.
 	// Doing filepath actions will convert it to a Windows path and break the init script.
 	if env.Platform() == WINDOWS && env.Shell() == "bash" {
+		env.Debug("Cygwin detected, using full path for config")
 		return
 	}
 	configFile := env.CmdFlags.Config
@@ -712,6 +728,7 @@ func (env *Shell) TemplateCache() *TemplateCache {
 	if env.tmplCache != nil {
 		return env.tmplCache
 	}
+
 	tmplCache := &TemplateCache{
 		Root:         env.Root(),
 		Shell:        env.Shell(),
@@ -719,8 +736,10 @@ func (env *Shell) TemplateCache() *TemplateCache {
 		Code:         env.ErrorCode(),
 		WSL:          env.IsWsl(),
 		Segments:     make(map[string]interface{}),
+		PromptCount:  env.CmdFlags.PromptCount,
 	}
 	tmplCache.Env = make(map[string]string)
+
 	const separator = "="
 	values := os.Environ()
 	for value := range values {
@@ -730,21 +749,25 @@ func (env *Shell) TemplateCache() *TemplateCache {
 		}
 		tmplCache.Env[key] = val
 	}
+
 	pwd := env.Pwd()
 	tmplCache.PWD = ReplaceHomeDirPrefixWithTilde(env, pwd)
 	tmplCache.Folder = Base(env, pwd)
 	if env.GOOS() == WINDOWS && strings.HasSuffix(tmplCache.Folder, ":") {
 		tmplCache.Folder += `\`
 	}
+
 	tmplCache.UserName = env.User()
 	if host, err := env.Host(); err == nil {
 		tmplCache.HostName = host
 	}
+
 	goos := env.GOOS()
 	tmplCache.OS = goos
 	if goos == LINUX {
 		tmplCache.OS = env.Platform()
 	}
+
 	env.tmplCache = tmplCache
 	return tmplCache
 }
@@ -764,6 +787,10 @@ func (env *Shell) DirMatchesOneOf(dir string, regexes []string) (match bool) {
 }
 
 func dirMatchesOneOf(dir, home, goos string, regexes []string) bool {
+	if len(regexes) == 0 {
+		return false
+	}
+
 	if goos == WINDOWS {
 		dir = strings.ReplaceAll(dir, "\\", "/")
 		home = strings.ReplaceAll(home, "\\", "/")
@@ -786,6 +813,38 @@ func dirMatchesOneOf(dir, home, goos string, regexes []string) bool {
 	return false
 }
 
+func (env *Shell) SetPromptCount() {
+	countStr := os.Getenv("POSH_PROMPT_COUNT")
+	if len(countStr) > 0 {
+		// this counter is incremented by the shell
+		count, err := strconv.Atoi(countStr)
+		if err == nil {
+			env.CmdFlags.PromptCount = count
+			return
+		}
+	}
+	var count int
+	if val, found := env.Cache().Get(PROMPTCOUNTCACHE); found {
+		count, _ = strconv.Atoi(val)
+	}
+	// only write to cache if we're the primary prompt
+	if env.CmdFlags.Primary {
+		count++
+		env.Cache().Set(PROMPTCOUNTCACHE, strconv.Itoa(count), 1440)
+	}
+	env.CmdFlags.PromptCount = count
+}
+
+func (env *Shell) CursorPosition() (row, col int) {
+	if number, err := strconv.Atoi(env.Getenv("POSH_CURSOR_LINE")); err == nil {
+		row = number
+	}
+	if number, err := strconv.Atoi(env.Getenv("POSH_CURSOR_COLUMN")); err != nil {
+		col = number
+	}
+	return
+}
+
 func IsPathSeparator(env Environment, c uint8) bool {
 	if c == '/' {
 		return true
